#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Wed Sep  8 18:50:45 2021

@author: patrick
"""

from .Facebook_Chat_Analysis import *
